/*
This is an Ozeki Audio Module example code.
The code listens to a microphone,
checks the intensity of the sound by checking the voltage.
The intensity is written on the serial from 0 to 255.
If the intensity is bigger then 140, the LED glows.
*/

volatile int value = 0;
 
ISR(ADC_vect){  //INTERRUPT activated when a selected ADC value has changed
                //in this code ADC5 is selected in the ADMUX register
 
  value = ADCH; //the first 8 bits of the 10 bit ADC value
                //the reamaining 2 bits are in ADCL
                // This is in the range of an electret microphone.
                // By default, the result is presented right adjusted,
                // but it can optionally be presented left adjusted
                // by setting the ADLAR bit in ADMUX.
                 
  ADCSRA|= _BV(ADSC); //sets ADSC bit to 1 to start each conversion
                      //ADSC resets to 0 after every conversion
}
 
void checkValue(){
  if ( value > 140){
        Serial.println(value); //the AD converted result of the microphone voltage
        digitalWrite(13,HIGH);
        delay(10);
    }
    else {
      Serial.println(0);
      digitalWrite(13,LOW);  
    }
  }
 
void setup() {
  Serial.begin(250000);
  pinMode(A5, INPUT);
  pinMode(13, OUTPUT);
   
  //ADMUX is the ADC Multiplexer Selection Register
  ADMUX|= _BV(REFS0)|_BV(ADLAR)|_BV(MUX2)|_BV(MUX0);
        //REFS0 are set to 1 to set ref voltage to AVCC
                //with external capacitor at AREF pin
        //ADLAR is set to 1 to present the ADCH bits left adjusted
        //MUX2 and MUX0 are set to 1 to set the input to ADC5
   
  //ADCSRA is the ADC Control and Status Register A
  ADCSRA|= _BV(ADEN)|_BV(ADIE)|_BV(ADPS1)|_BV(ADPS0);
        //ADEN set to 1 enables the ADConverter (ADC)
        //ADIE set to 1 activates the ADC Conversion Complete Interrupt
        //ADPS1 and ADPS0 are set to 1 to set the division factor to 8
        //between the XTAL frequency and the input clock to the ADC.
  ADCSRA|= _BV(ADSC); //sets ADSC bit to 1 to start each conversion
}
 
void loop() {
  checkValue();
}
